pub struct RoadDetails {
pub event_id: EventId,
pub start_date: Date,
pub end_date: Date,
pub service_dept: String,
pub road_name: String,
pub other: String,
}Fields
event_id: EventIdUnique identifier of a road work or road opening event.
start_date: DateDate on which the road work starts.
end_date: DateDate on which the road work ends.
service_dept: StringAgency responsible for the road work.
road_name: StringName of the road affected by the road work.
other: StringAdditional information about the road work.